﻿#region License
/*
Kangaroo Library for C# and .NET
Copyright (c) 2013 Dimension Engineering LLC
http://www.dimensionengineering.com/kangaroo

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#endregion

using System;
using System.Threading;
using DimensionEngineering.Kangaroo;

// This advanced example demonstrates how to programmatically start a tune using Packet Serial.
// It is currently set up to try starting a tune with Limit Switches.

// USB TTL Serial TX  goes to Kangaroo S1
// USB TTL Serial RX  goes to Kangaroo S2
// USB TTL Serial GND goes to Kangaroo 0V
// Make sure to change the PortName constant.

namespace Examples.ProgrammaticTune
{
    class Program
    {
        const string PortName = "COM148"; // <-- Your serial port name goes here (COM1, COM2, etc.).
        const int TuneMode = 2;           // <-- Change this to the mode you want. Mode 2 is Limit Switches.

        static KangarooSerial K;
        static KangarooChannel K1;
        static KangarooChannel K2;

        static void Setup()
        {
            K = new KangarooSerial();
            K.Open(PortName);

            K1 = new KangarooChannel(K, '1');
            K2 = new KangarooChannel(K, '2');

            // Give the Kangaroo some time to power up.
            Thread.Sleep(2000);

            // Enter the desired tune mode.
            K1.SystemCommand(KangarooSystemCommand.TuneEnterMode, false, TuneMode);

            // Set the disabled channel bitmask to 0 (tune all channels).
            K1.SystemCommand(KangarooSystemCommand.TuneSetDisabledChannels, false, 0);

            // Begin the tune.
            K1.SystemCommand(KangarooSystemCommand.TuneGo, false);
        }

        static void Loop()
        {
            // Tuning has an automatic serial timeout for safety reasons.
            // You must continually send packets or it will abort. GetP() in a loop does the job.
            K1.GetP();
        }

        static void Main(string[] args)
        {
            Setup();
            while (true) { Loop(); }
        }
    }
}
