﻿#region License
/*
Kangaroo Library for C# and .NET
Copyright (c) 2013 Dimension Engineering LLC
http://www.dimensionengineering.com/kangaroo

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#endregion

using System;
using System.IO;

namespace DimensionEngineering.Kangaroo
{
    sealed class KangarooCommandWriter
    {
        public KangarooCommandWriter()
        {

        }

        public void Write(byte data)
        {
            _data[_length++] = data;
        }

        public void Write(byte[] data, int offset, int count)
        {
            for (int i = 0; i < count; i++) { Write(data[offset + i]); }
        }

        public void WriteBitPackedNumber(int number)
        {
            number = Math.Max(-KangarooConstants.BitPackedMaxValue, Math.Min(KangarooConstants.BitPackedMaxValue, number));

            uint encodedNumber;
            if (number < 0) { encodedNumber = (uint)(-number); encodedNumber <<= 1; encodedNumber |= 1; }
            else { encodedNumber = (uint)number; encodedNumber <<= 1; }

            do
            {
                Write((byte)((byte)(encodedNumber & 0x3f) | (byte)(encodedNumber >= 0x40 ? 0x40 : 0x00)));
                encodedNumber >>= 6;
            }
            while (encodedNumber != 0);
        }

        public int WriteToBuffer(byte[] buffer, int offset, int address, KangarooCommand command)
        {
            return WriteToBuffer(buffer, offset, address, command, Buffer, Offset, Length);
        }

        public static int WriteToBuffer(byte[] buffer, int offset, int address, KangarooCommand command,
                                        byte[] data, int offsetOfData, int lengthOfData)
        {
            int i = offset;
  
            buffer[i++] = (byte)address;
            buffer[i++] = (byte)command;
            buffer[i++] = (byte)lengthOfData;
            for (byte j = 0; j < lengthOfData; j ++) { buffer[i ++] = data[offsetOfData + j]; }
  
            ushort crc = KangarooCRC.Value(buffer, 0, i - offset);
            buffer[i++] = (byte)(crc & 0x7f);
            buffer[i++] = (byte)((crc >> 7) & 0x7f);
  
            return i - offset;
        }

        public void WriteToStream(Stream port, int address, KangarooCommand command)
        {
            WriteToStream(port, address, command, Buffer, Offset, Length);
        }

        public static void WriteToStream(Stream port, int address, KangarooCommand command,
                                         byte[] data, int offsetOfData, int lengthOfData)
        {
            byte[] buffer = new byte[KangarooConstants.CommandMaxBufferLength];
            int lengthOfBuffer = WriteToBuffer(buffer, 0, address, command, data, offsetOfData, lengthOfData);
            port.Write(buffer, 0, lengthOfBuffer);
        }

        public byte[] Buffer
        {
            get { return _data; }
        }

        public int Offset
        {
            get { return 0; }
        }

        public int Length
        {
            get { return _length; }
        }

        int _length;
        byte[] _data = new byte[KangarooConstants.CommandMaxDataLength];
    }
}
