﻿#region License
/*
Kangaroo Library for C# and .NET
Copyright (c) 2013 Dimension Engineering LLC
http://www.dimensionengineering.com/kangaroo

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#endregion

using System;

namespace DimensionEngineering.Kangaroo
{
    /// <summary>
    /// Flags that provide details about a query response.
    /// </summary>
    [Flags]
    public enum KangarooStatusFlags
    {
        /// <summary>
        /// The response is normal.
        /// </summary>
        None = 0x00,

        /// <summary>
        /// The response is an error.
        /// </summary>
        Error = 0x01,

        /// <summary>
        /// For a motion, this means the motion is not finished. For an error, this means the error (such as <see cref="KangarooError.NotHomed"/>) should self-clear. This corresponds to a lowercase letter in Simplified Serial.
        /// </summary>
        Busy = 0x02,

        EchoCode = 0x10,

        /// <summary>
        /// The value in the response is in raw units. For analog, raw units are millivolts. For quadrature, 4 raw units equal 1 line.
        /// </summary>
        RawUnits = 0x20,

        SequenceCode = 0x40
    }
}
