﻿#region License
/*
Kangaroo Library for C# and .NET
Copyright (c) 2013 Dimension Engineering LLC
http://www.dimensionengineering.com/kangaroo

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT,
NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE
USE OR PERFORMANCE OF THIS SOFTWARE.
*/
#endregion

using System;

namespace DimensionEngineering.Kangaroo
{
    /// <summary>
    /// Advanced commands that have special effects on the Kangaroo motion controller.
    /// </summary>
    public enum KangarooSystemCommand
    {
        /// <summary>
        /// Powers down the channel.
        /// </summary>
        PowerDown = 0x00,

        /// <summary>
        /// Powers down all channels of the controller that receives the command.
        /// </summary>
        PowerDownAll = 0x01,

        /// <summary>
        /// Enters tune mode 1 (Teach), 2 (Limit Switches), or 3 (Mechanical Stops).
        /// This corresponds to pressing the tune button multiple times to get into the mode you want.
        ///
        /// Do not expect a reply from this command.
        /// </summary>
        TuneEnterMode = 0x03,

        /// <summary>
        /// Begins the tune.
        /// This corresponds to pressing the tune button after you are in the desired mode.
        /// 
        /// Tuning has an automatic serial timeout for safety reasons.
        /// You must continually send packets or it will abort. <see cref="KangarooChannel.GetP"/> in a loop does the job.
        /// 
        /// Do not expect a reply from this command.
        /// </summary>
        TuneGo = 0x04,

        /// <summary>
        /// Aborts the tune.
        /// 
        /// Do not expect a reply from this command.
        /// </summary>
        TuneAbort = 0x05,

        /// <summary>
        /// Sets the open loop power. This can be used to position for a Teach tune.
        /// The range is -(2^28-1) to 2^28-1.
        /// 
        /// Do not expect a reply from this command.
        /// </summary>
        TuneControlOpenLoop = 0x06,

        /// <summary>
        /// Initially all channels are disabled for safety reasons after entering a tune mode.
        /// You must send this bitmask before beginning the tune. 0 enables all channels.
        /// 
        /// Do not expect a reply from this command.
        /// </summary>
        TuneSetDisabledChannels = 0x08,

        /// <summary>
        /// Sets the baud rate.
        /// 
        /// Do not expect a reply from this command.
        /// </summary>
        SetBaudRate = 0x20,

        /// <summary>
        /// Sets the serial timeout.
        /// </summary>
        SetSerialTimeout = 0x21
    }
}
